.. _json2gff:

json2gff - Convert JSON to GFF
==============================

Overview
--------

.. automodule:: mgkit.workflow.json2gff


Options
-------

.. click:: mgkit.workflow.json2gff:main
   :prog: json2gff
   :show-nested:
